Documentation
¶
Overview ¶
Package tmpllib enshrines in code the common practice of managing a directory of HTML templates, all of which depend on a root template called, fittingly, "root.html."
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
Execute sends to the given Writer the output of evaluating a template with the given name on the given object.
func Load ¶
Load scans the given directory and generates html template objects for each file found. Each template object is the reslt of parsing a file preceded by the "root.html" file. Files are scanned in lexicographic order, and no template is created for the contents of "root.html".
Types ¶
Source Files
¶
- main.go
Click to show internal directories.
Click to hide internal directories.